==> ejc-purchasingmanagement-impl-3.0.0-20220611.073322-111-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialpaymentdetailVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商付款单明细
 * 
 * @author generator
 * 
 */
public class MaterialpaymentdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialpaymentId; // 供应商付款单主键
    private Long materialacceptanceId; // 材料验收主键
    private Long materialId; // 原材料id
    private String materialName; // 原材料名称
    private Date acceptanceDate; // 日期
    private BigDecimal quantity; // 数量
    private BigDecimal amount; // 金额
    private BigDecimal uncollectedMoney; // 未付金额
    private BigDecimal receivedMoney; // 本单已付金额
    private BigDecimal otherReceivedMoney; // 其他单已付金额
    private BigDecimal receivableMoney; // 应付金额
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String billCode; // 供应商付款单单据号
    private BigDecimal distributionMoney; // 分配金额

    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialpaymentId() {
        return materialpaymentId;
    }

    public void setMaterialpaymentId(Long materialpaymentId) {
        this.materialpaymentId = materialpaymentId;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getReceivableMoney() {
        return receivableMoney;
    }

    public void setReceivableMoney(BigDecimal receivableMoney) {
        this.receivableMoney = receivableMoney;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20221017.091328-230-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialpaymentdetailVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 供应商付款单明细
 * 
 * @author generator
 * 
 */
public class MaterialpaymentdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialpaymentId; // 供应商付款单主键
    private Long materialacceptanceId; // 材料验收主键
    private Long materialId; // 原材料id
    private String materialName; // 原材料名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date acceptanceDate; // 日期
    private BigDecimal quantity; // 数量
    private BigDecimal amount; // 金额
    private BigDecimal uncollectedMoney; // 未付金额
    private BigDecimal receivedMoney; // 本单已付金额
    private BigDecimal otherReceivedMoney; // 其他单已付金额
    private BigDecimal receivableMoney; // 应付金额
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String billCode; // 供应商付款单单据号
    private BigDecimal distributionMoney; // 分配金额

    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialpaymentId() {
        return materialpaymentId;
    }

    public void setMaterialpaymentId(Long materialpaymentId) {
        this.materialpaymentId = materialpaymentId;
    }
    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getReceivableMoney() {
        return receivableMoney;
    }

    public void setReceivableMoney(BigDecimal receivableMoney) {
        this.receivableMoney = receivableMoney;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}
